pub struct MleDescription<F: Field> {
layer_id: LayerId,
var_indices: Vec<MleIndex<F>>,
}Expand description
A metadata-only version of crate::mle::dense::DenseMle used in the Circuit
Descrption. A MleDescription is stored in the leaves of an Expression<F, ExprDescription> tree.
Fields
layer_id: LayerIdLayer whose data this MLE’s is a subset of.
var_indices: Vec<MleIndex<F>>A list of indices where the free variables have been assigned an index.
Implementations
Sourceimpl<F: Field> MleDescription<F>
impl<F: Field> MleDescription<F>
Sourcepub fn new(layer_id: LayerId, var_indices: &[MleIndex<F>]) -> Self
pub fn new(layer_id: LayerId, var_indices: &[MleIndex<F>]) -> Self
Create a new MleDescription given its layer id and the MleIndexs that it holds. This is effectively the “shape” of a DenseMle.
Sourcepub fn set_mle_indices(&mut self, new_mle_indices: Vec<MleIndex<F>>)
pub fn set_mle_indices(&mut self, new_mle_indices: Vec<MleIndex<F>>)
Replace the current MLE indices stored with custom MLE indices. Most useful in crate::layer::matmult::MatMult, where we do index manipulation.
Sourcepub fn index_mle_indices(&mut self, start_index: usize)
pub fn index_mle_indices(&mut self, start_index: usize)
Convert MleIndex::Free into MleIndex::Indexed with the correct index labeling, given by start_index parameter.
Sourcepub fn var_indices(&self) -> &[MleIndex<F>]
pub fn var_indices(&self) -> &[MleIndex<F>]
Returns the MLE indices of this MleDescription.
Sourcepub fn num_free_vars(&self) -> usize
pub fn num_free_vars(&self) -> usize
The number of MleIndex::Indexed OR MleIndex::Free bits in this MLE.
Sourcepub fn prefix_bits(&self) -> Vec<bool>
pub fn prefix_bits(&self) -> Vec<bool>
Get the bits in the MLE that are fixed bits.
Sourcepub fn into_dense_mle(&self, circuit_map: &CircuitEvalMap<F>) -> DenseMle<F>
pub fn into_dense_mle(&self, circuit_map: &CircuitEvalMap<F>) -> DenseMle<F>
Convert this MLE into a DenseMle using the CircuitEvalMap, which holds information using the prefix bits and layer id on the data that should be stored in this MLE.
Sourcepub fn fix_variable(&mut self, var_index: usize, value: F)
pub fn fix_variable(&mut self, var_index: usize, value: F)
Bind the variable with index var_index to value. Note that since
MleDescription is the representation of a multilinear extension function
sans data, it need not alter its internal MLE evaluations in any way.
Sourcepub fn get_claim_point(&self, challenges: &[F]) -> Vec<F>
pub fn get_claim_point(&self, challenges: &[F]) -> Vec<F>
Gets the values of the bound and fixed MLE indices of this MLE, panicking if the MLE is not fully bound.
Sourcepub fn into_verifier_mle(
&self,
point: &[F],
transcript_reader: &mut impl VerifierTranscript<F>,
) -> Result<VerifierMle<F>>
pub fn into_verifier_mle( &self, point: &[F], transcript_reader: &mut impl VerifierTranscript<F>, ) -> Result<VerifierMle<F>>
Convert this MLE into a VerifierMle, which represents a fully-bound MLE.